@@ -50,49 +50,30 @@ class CommentForm(ModelForm):
             
 
 class CategoryForm(ModelForm):
-    category_sites = forms.ModelMultipleChoiceField(queryset=Site.objects.all(), widget=forms.CheckboxSelectMultiple, label=_("Sites"))
-    category_excluded_sites = forms.ModelMultipleChoiceField(queryset=Site.objects.all(), widget=forms.CheckboxSelectMultiple, label=_("Excluded sites"), required=False)
-    
+
     class Meta:
         model = Category
-        fields = ['category', 'global_category', 'category_sites', 'category_excluded_sites']
-
-    def __init__(self, staff, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        if not staff:
-            self.fields.pop('category_sites')
-            self.fields.pop('global_category')
-            self.fields.pop('category_excluded_sites')
-        else:
-            self.fields['global_category'].label = _("Global Category? (Appears on all sites except excluded sites)")
+        fields = ['category']
 
 
 class QuestionForm(ModelForm):
-    sites = forms.ModelMultipleChoiceField(queryset=Site.objects.all(), widget=forms.CheckboxSelectMultiple, required=False)
-    excluded_sites = forms.ModelMultipleChoiceField(queryset=Site.objects.all(), widget=forms.CheckboxSelectMultiple, required=False)
 
     class Meta:
         model = Question
-        fields = ['question', 'answer', 'category', 'global_question', 'sites', 'excluded_sites']
+        fields = ['question', 'answer', 'category']
 
-    def __init__(self, staff, *args, **kwargs):
+    def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        if not staff:
-            self.fields.pop('sites')
-            self.fields.pop('global_question')
-            self.fields.pop('excluded_sites')
 
-            # limit the possible categories to the current site
-            current_site = Site.objects.get_current()
-            self.fields['category'].queryset = Category.objects.filter(category_sites__in=[current_site])
-        else:
-            self.fields['global_question'].label = _("Global Question? (Appears on all sites except excluded sites)")
+        # limit the possible categories to the current site
+        current_site = Site.objects.get_current()
+        self.fields['category'].queryset = Category.objects.filter(category_sites__in=[current_site])
 
 
 class TeamForm(ModelForm):
     # get users with explicit support permissions
     # as well as admins with all permissions
-    member_qs = get_user_model().objects.filter(user_permissions__codename="see-support-tickets") | get_user_model().objects.filter(is_superuser=True)
+    member_qs = get_user_model().objects.filter(user_permissions__codename="see_support_tickets") | get_user_model().objects.filter(is_superuser=True)
     members = forms.ModelMultipleChoiceField(queryset=member_qs.distinct(), widget=forms.CheckboxSelectMultiple)
 
     class Meta:
